[![Build Status](https://github.com/alejoe91/MEAutility/actions/workflows/python-package.yml/badge.svg)](https://github.com/alejoe91/MEAutility/actions/workflows/python-package.yml/badge.svg) [![PyPI version](https://badge.fury.io/py/MEAutility.svg)](https://badge.fury.io/py/MEAutility)

# MEAutility

Python package for multi-electrode array (MEA) handling and stimulation.

## Installation

To install run:
`pip install MEAutility`

If you want to install from sources and be updated with the latest development you can install with:
```
git clone https://github.com/alejoe91/MEAutility
cd MEAutility
pip install -e .
```

The package can then imported in Python with:

`import MEAutility as MEA`

## Documentation

Please refer to https://meautility.readthedocs.io/en/latest/ 

## Contact

For any questions or comments, please contact Alessio Buccino: alessiop.buccino@gmail.com
